pub fn negotiate_runner_features(
host: &[PythonRunnerFeature],
worker: &[PythonRunnerFeature],
) -> Vec<PythonRunnerFeature>Expand description
Return the deterministic feature intersection in host preference order.
pub fn negotiate_runner_features(
host: &[PythonRunnerFeature],
worker: &[PythonRunnerFeature],
) -> Vec<PythonRunnerFeature>Return the deterministic feature intersection in host preference order.