pub struct PythonInvocationRequest {
pub invocation_id: String,
pub request_id: String,
pub provider: String,
pub action: String,
pub arguments: Value,
pub surface: ProviderSurface,
pub snapshot_id: String,
pub deadline_unix_ms: u64,
pub trace: Option<PythonTraceContext>,
pub actor: Option<PythonActorContext>,
pub cancellation_token_id: String,
pub generation_id: String,
}Expand description
Complete at-most-once invocation envelope.
Fields
invocation_id: Stringrequest_id: StringSurface request identity; unlike the numeric frame id this remains stable across runtime boundaries.
provider: Stringaction: Stringarguments: Valuesurface: ProviderSurfacesnapshot_id: Stringdeadline_unix_ms: u64trace: Option<PythonTraceContext>actor: Option<PythonActorContext>cancellation_token_id: Stringgeneration_id: StringTrait Implementations
Sourceimpl Clone for PythonInvocationRequest
impl Clone for PythonInvocationRequest
Sourcefn clone(&self) -> PythonInvocationRequest
fn clone(&self) -> PythonInvocationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonInvocationRequest
impl Debug for PythonInvocationRequest
Sourceimpl<'de> Deserialize<'de> for PythonInvocationRequest
impl<'de> Deserialize<'de> for PythonInvocationRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PythonInvocationRequest
impl PartialEq for PythonInvocationRequest
Sourcefn eq(&self, other: &PythonInvocationRequest) -> bool
fn eq(&self, other: &PythonInvocationRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PythonInvocationRequest
impl Serialize for PythonInvocationRequest
impl StructuralPartialEq for PythonInvocationRequest