pub struct PythonRunnerError {
pub code: PythonRunnerErrorCode,
pub phase: PythonRunnerErrorPhase,
pub provider: Option<String>,
pub source: Option<String>,
pub generation_id: Option<String>,
pub action: Option<String>,
pub retryable: bool,
pub public_message: String,
}Expand description
Redacted error envelope safe to cross the private runner protocol.
Fields
code: PythonRunnerErrorCodephase: PythonRunnerErrorPhaseprovider: Option<String>source: Option<String>generation_id: Option<String>action: Option<String>retryable: boolpublic_message: StringTrait Implementations
Sourceimpl Clone for PythonRunnerError
impl Clone for PythonRunnerError
Sourcefn clone(&self) -> PythonRunnerError
fn clone(&self) -> PythonRunnerError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonRunnerError
impl Debug for PythonRunnerError
Sourceimpl<'de> Deserialize<'de> for PythonRunnerError
impl<'de> Deserialize<'de> for PythonRunnerError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PythonRunnerError
impl PartialEq for PythonRunnerError
Sourcefn eq(&self, other: &PythonRunnerError) -> bool
fn eq(&self, other: &PythonRunnerError) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PythonRunnerError
impl Serialize for PythonRunnerError
impl Eq for PythonRunnerError
impl StructuralPartialEq for PythonRunnerError